@@ -11,7 +11,7 @@ use Carp;
 # module.
 
 
-our $VERSION = '0.4';
+our $VERSION = '0.2';
 
 =head1 NAME
 
@@ -66,7 +66,6 @@ use Apache::AxKit::Exception;
 use Apache::AxKit::Provider;
 
 use AxKit;
-use AxKit::App::TABOO;
 use AxKit::App::TABOO::Data::Story;
 use AxKit::App::TABOO::Data::Plurals::Stories;
 use AxKit::App::TABOO::Data::Category;
@@ -74,6 +73,8 @@ use AxKit::App::TABOO::Data::Plurals::Categories;
 use AxKit::App::TABOO::Data::Article;
 use AxKit::App::TABOO::Data::Plurals::Articles;
 
+use Apache::AxKit::Plugin::BasicSession;
+
 
 sub init {
   my $self = shift;
@@ -82,14 +83,13 @@ sub init {
   
   AxKit::Debug(10, "[Classification] Request object: " . $r->as_string);
   AxKit::Debug(8, "[Classification] Provider using URI " . $r->uri);
-
+  
+ 
   $self->{uri} = $r->uri;
   my @uri = split('/', $r->uri);
   splice(@uri, 0, 2); # The first part is just a keyword,
   $self->{cats} = \@uri;
 
-  $self->{session} = AxKit::App::TABOO::session($r);
-
   AxKit::Debug(9, "[Classification] Data parsed in init: " . Dumper($self));
   return $self;
 }
@@ -113,7 +113,7 @@ sub process {
     $self->{stories} = AxKit::App::TABOO::Data::Plurals::Stories->new();
     unless ($self->{articles}->incat(@{$self->{cats}})) {
       $self->{articles} = undef;
-      unless ($self->{stories}->exists(catname => @{$self->{cats}})) { 
+      unless ($self->{stories}->incat(@{$self->{cats}})) { 
 	$self->{exists} = 0;
       }
     }
@@ -133,8 +133,9 @@ sub exists {
 
 
 sub key {
+  no warnings; # To avoid warning when no credential_0 exists
   my $self = shift;
-  return $self->{uri} . "/" . AxKit::App::TABOO::loggedin($self->{session});
+  return $self->{uri} . "/" . $Apache::AxKit::Plugin::BasicSession::session{credential_0};
 }
 
 
@@ -157,12 +158,11 @@ sub get_dom {
 					     return_code => 404,
 					     -text => "Category " . $self->{catnotfound} . " was not found");
     }
-#    warn "ANT: " . Dumper($self);
-    my $authlevel = AxKit::App::TABOO::authlevel($self->{session});
+    warn "ANT: " . Dumper($self);
     if (scalar(@{$self->{cats}}) == 1) {
       my %limit;
-      if (! defined($authlevel)
-	  || ($authlevel < 4)) {
+      if (! defined($Apache::AxKit::Plugin::BasicSession::session{authlevel})
+	  || ($Apache::AxKit::Plugin::BasicSession::session{authlevel} < 4)) {
 	$limit{'editorok'} = 1;
       } elsif ($self->{editor}) {
 	$limit{'editorok'} = 0;
@@ -189,8 +189,8 @@ sub get_dom {
     my $anyarticles = 0;
     if($self->{articles}) {
       my %limit;
-      if (! defined($authlevel)
-	  || ($authlevel < 4)) {
+      if (! defined($Apache::AxKit::Plugin::BasicSession::session{authlevel})
+	  || ($Apache::AxKit::Plugin::BasicSession::session{authlevel} < 4)) {
 	$limit{'editorok'} = 1;
 	$limit{'authorok'} = 1;
       }
@@ -206,7 +206,7 @@ sub get_dom {
     warn Dumper($self->{articles});
     
     unless (($anyarticles) || (defined($self->{stories}))) {
-      if (defined($authlevel)) {
+      if (defined($Apache::AxKit::Plugin::BasicSession::session{authlevel})) {
 	throw Apache::AxKit::Exception::Retval(
 					       return_code => 403,
 					       -text => "Articles or stories exist, but are only accessible to editors.");
