@@ -6,8 +6,7 @@ use Apache::AxKit::Language::XSP::SimpleTaglib;
 use Apache::AxKit::Exception;
 use AxKit;
 use AxKit::App::TABOO::Data::Article;
-use AxKit::App::TABOO;
-use Session;
+use Apache::AxKit::Plugin::BasicSession;
 use Time::Piece ':override';
 use XML::LibXML;
 use IO::File;
@@ -15,7 +14,7 @@ use MIME::Type;
 
 use vars qw/$NS/;
 
-our $VERSION = '0.4';
+our $VERSION = '0.2';
 
 =head1 NAME
 
@@ -80,121 +79,45 @@ sub _sanatize_filename {
 }
 
 sub _write_file {
-    my %args = @_;
+    my $upload = shift;
+    my $primcat = shift;
+    my $docroot = shift;
     my $fh = new IO::File;
-    my $filename = $args{filename};
-    my $ext = $args{extension} || 'txt';
-    if ($args{upload}) {
-	($filename, $ext) = $args{upload}->filename =~ m/^(.*)\.(\w*)$/;
-    }
+    my ($filename, $ext) = $upload->filename =~ m/^(.*)\.(\w*)$/;
     $filename = _sanatize_filename($filename);
-    my $i = 0;
-    while (-e $args{docroot} ."/articles/content/$args{primcat}/$filename/$filename.$ext") { # Append an incrementing number if the file exists
-	$i++;
-	if ($i == 1) {
-	    $filename .= '-' . $i;
-	} else {
-	    $filename =~ s/-\d+$/-$i/;
-	}
-	die "Can't really be $i identical files here, can it?" if ($i >= 100);
-    }
-    my $lookupfile = $args{docroot} ."/articles/content/$args{primcat}/$filename/";
-    my $dir;
-    foreach my $name (split('/', $lookupfile)) { # Make sure all dirs exist
-	$dir .= $name . '/';
-	unless (-d $dir) {
-	    mkdir ($dir, 0775) || die "Failed to create directory " . $dir;
-	}
-    }
+    my $lookupfile = $docroot ."/articles/content/$primcat/$filename/";
+    mkdir $lookupfile, 0775 || die "Failed to create directory " . $lookupfile;
     $lookupfile .= "$filename.$ext";
     if ($fh->open("> " . $lookupfile)) {
-	if ($args{upload}) {
-	    my $uploadedfh = $args{upload}->fh;
-	    while (<$uploadedfh>) {
-		print $fh $_;
-	    }
-	} else {
-	    die "Error saving string to filename $filename.$ext" unless (($filename) && ($args{text}));
-	    print $fh $args{text};
+	my $uploadedfh = $upload->fh;
+	while (<$uploadedfh>) {
+	    print $fh $_;
 	}
 	$fh->close;
     } else { die "Failed to open file at $lookupfile for writing"  }
-    return $filename;
+    return "/articles/content/$primcat/$filename/$filename.$ext";
 }
 
 package AxKit::App::TABOO::XSP::Article::Handlers;
 
 =head1 Tag Reference
 
-
-=head2 C<E<lt>store-required/E<gt>>
-
-This tag will check and store the data from the required fields. It
-will check for either uploaded files, and the MIME types of that, or
-take plain text and save it to a local file. It doesn't do many
-security checks yet.
-
-If the save was successful, it will redirect to C</articles/edit>, so
-that the submitter can continue editing of non-required fields. To
-control where it redirects to, you should supply an attribute or child
-element C<redirect> containing the URL of the page to redirect to and
-C<retval>, with the HTTP return value. The latter defaults to 302.
-
-If something went wrong, the tag will return a nodelist
-C<problem>. The nodelist will contain the data store name of the
-field(s) that weren't present, or C<nosave> if the save itself failed.
-
 =cut
 
 
-sub store_required : nodelist({http://www.kjetil.kjernsmo.net/software/TABOO/NS/Article/Output}art:problem) attribOrChild(redirect,retval) {
-  return << 'EOC'
-  my @errors = ();
-  foreach my $required (qw(title authorid description primcat code)) {
-      unless ($cgi->param($required)) {
-	  push(@errors, $required);
-      }
-  }
-  unless ((($cgi->param('text')) && ($cgi->param('filename'))) || ($cgi->param('upfile'))) {
-      foreach my $required (qw(text filename upfile)) {
-	  unless ($cgi->param($required)) {
-	      push(@errors, $required);
-	  }
-      }
-  }
+sub store : node({http://www.kjetil.kjernsmo.net/software/TABOO/NS/Article/Output}store) {
+    return << 'EOC'
+      my $fh = new IO::File;
+      my $upload =  $cgi->upload->fh;
+      if ($fh->open("> /tmp/dahut")) {
+      while (<$upload>) {
+        print $fh $_;
+}
+        $fh->close;
 
-  unless (@errors) { # OK, so far, so good
-      my %args = map { $_ => $cgi->param($_) } $cgi->param;
-      
-      my $upload = $cgi->upload;
-      if ($upload->size > 0) {
-	  $args{'filename'} = AxKit::App::TABOO::XSP::Article::_write_file(upload=>$upload, primcat => $args{'primcat'}, docroot=>$r->document_root);
-	  $args{'mimetype'} = $upload->type;
-      } else {
-	  $args{'filename'} = AxKit::App::TABOO::XSP::Article::_write_file(filename=>$args{'filename'}, text=>$args{'text'}, primcat => $args{'primcat'}, docroot=>$r->document_root);
-	  $args{'mimetype'} = 'text/plain';
-      }
-      # TODO: Security sanity checks.
-      $args{'authorok'} = 1; # Is assumed for now
-      unless ($args{'date'}) {
-	  my $timestamp = localtime;
-	  $args{'date'} = $timestamp->datetime;
-      }
-      my $article = AxKit::App::TABOO::Data::Article->new();
-      $article->populate(\%args, [[$args{'primcat'}, 'primcat']], [$args{'authorid'}]);
-      unless($article->save) {
-	  push(@errors, 'nosave');
-      }
-  }
-      
-  unless (@errors) { # Actually, everything went fine here, so we redirect to continue
-    $cgi->status($attr_retval || 302);
-    $cgi->err_headers_out->add("Location" => $attr_redirect || '/');
-    Apache::exit($attr_retval || 302);
-  } else { 
-    AxKit::Debug(9, "Things that went wrong: " . join(' ', @errors));
-  }
-  @errors;
+    } else { die "screaming" }
+
+    1;
 EOC
 }
 
@@ -228,34 +151,24 @@ EOC
 }
 
 
-=head2 C<E<lt>get-article filename="foo" primcat="bar"/E<gt>>
-
-This tag will get an XML representation of the article identified with
-C<filename> and C<primcat>. The parameters may be given as attributes
-or child elements.
-
-=cut
-
 
 sub get_article : struct attribOrChild(filename,primcat) {
-   # return << 'EOC'
-    AxKit::Debug(8, "We look for article with filename: '" . $attr_filename . "'");
+    return << 'EOC'
     my $article = AxKit::App::TABOO::Data::Article->new();
     unless ($article->load(limit => { filename => $attr_filename })) {
 	throw Apache::AxKit::Exception::Retval(
 					       return_code => 404,
 					       -text => "Article with identifier $attr_filename not found");
     }	
+
     unless ($article->editorok && $article->authorok) {
-        my $session = AxKit::App::TABOO::session($r);
-	my $authlevel = AxKit::App::TABOO::authlevel($session);
-	if (!$authlevel) {
+	if (! $Apache::AxKit::Plugin::BasicSession::session{authlevel}) {
 	    throw Apache::AxKit::Exception::Retval(
 						   return_code => 401,
 						   -text => "Not authorised with an authlevel");
 	}
-	my $editinguser = AxKit::App::TABOO::loggedin($session);
-	unless (grep(/$editinguser/, @{$article->authorids}) || ($authlevel >= 5)) {
+	unless (grep(/$Apache::AxKit::Plugin::BasicSession::session{credential_0}/, @{$article->authorids}) || 
+		($Apache::AxKit::Plugin::BasicSession::session{authlevel} >= 5)) {
 	    throw Apache::AxKit::Exception::Retval(
 						   return_code => 403,
 						   -text => "Authentication and higher priviliges required to load article");
@@ -269,7 +182,6 @@ sub get_article : struct attribOrChild(filename,primcat) {
     my $lookupurl;
     foreach my $ext ($article->mimetype->extensions) {
 	my $lookupfile = "/articles/content/$attr_primcat/$attr_filename/$attr_filename.$ext";
-	warn $r->document_root . $lookupfile;
 	if (-r $r->document_root . $lookupfile) {
 	    $lookupurl = 'http://' . $r->get_server_name . ':' . $r->get_server_port . $lookupfile;
 	}
